@@ -21,6 +21,11 @@
 #ifndef _LIBICONV_H
 #define _LIBICONV_H
 
+#ifdef __FreeBSD__
+#define LIBICONV_PLUG
+#endif
+
+
 #define _LIBICONV_VERSION 0x0108    /* version number: (major<<8) + minor */
 extern int _libiconv_version;       /* Likewise */
 
@@ -55,7 +60,7 @@ typedef void* iconv_t;
    have EILSEQ in a different header.  On these systems, define EILSEQ
    ourselves. */
 #ifndef EILSEQ
-#define EILSEQ 
+#define EILSEQ ENOENT
 #endif
 
 
@@ -68,6 +73,8 @@ extern "C" {
    encoding `tocode'. */
 #ifndef LIBICONV_PLUG
 #define iconv_open libiconv_open
+#else
+#define libiconv_open iconv_open
 #endif
 extern iconv_t iconv_open (const char* tocode, const char* fromcode);
 
@@ -78,17 +85,21 @@ extern iconv_t iconv_open (const char* tocode, const char* fromcode);
    Decrements `*outbytesleft' and increments `*outbuf' by the same amount. */
 #ifndef LIBICONV_PLUG
 #define iconv libiconv
+#else
+#define libiconv iconv
 #endif
 extern size_t iconv (iconv_t cd, const char* * inbuf, size_t *inbytesleft, char* * outbuf, size_t *outbytesleft);
 
 /* Frees resources allocated for conversion descriptor `cd'. */
 #ifndef LIBICONV_PLUG
 #define iconv_close libiconv_close
+#else
+#define libiconv_close iconv_close
 #endif
 extern int iconv_close (iconv_t cd);
 
 
-#ifndef LIBICONV_PLUG
+#if !defined(LIBICONV_PLUG) || defined(__FreeBSD__)
 
 /* Nonstandard extensions. */
 
